@@ -4,9 +4,7 @@
 // Invenio RDM Records is free software; you can redistribute it and/or modify it
 // under the terms of the MIT License; see LICENSE file for more details.
 
-import {
-  fetchTimeline
-} from '@js/invenio_requests/timeline/state/actions';
+import { fetchTimeline } from "../../timeline/state/actions";
 
 export const REQUEST_INIT = "request/INIT";
 
@@ -19,13 +17,19 @@ export const initRequest = () => {
   };
 };
 
-export const updateRequestAfterAction = (request) => {
+export const updateRequest = (request) => {
   return async (dispatch, getState, config) => {
     dispatch({
       type: REQUEST_INIT,
       payload: request,
     });
-    dispatch(fetchTimeline());
+  };
+};
+
+export const updateRequestAfterAction = (request) => {
+  return async (dispatch, getState, config) => {
+    dispatch(updateRequest(request));
+    window.location.reload();
   };
 };
 
@@ -34,4 +38,3 @@ export const setRefreshInterval = () => {
     return config.refreshIntervalMs;
   };
 };
-
