@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2021 CERN.
-# Copyright (C) 2021 Northwestern University.
-# Copyright (C) 2021 TU Wien.
+# Copyright (C) 2021-2022 CERN.
+# Copyright (C) 2021-2022 Northwestern University.
+# Copyright (C) 2021-2022 TU Wien.
 #
 # Invenio-Requests is free software; you can redistribute it and/or modify it
 # under the terms of the MIT License; see LICENSE file for more details.
@@ -15,15 +15,15 @@ from invenio_access.permissions import system_process
 from invenio_records_resources.services import RecordService, ServiceSchemaWrapper
 from invenio_records_resources.services.base.links import LinksTemplate
 from invenio_records_resources.services.uow import (
-    IndexRefreshOp,
     RecordCommitOp,
     RecordDeleteOp,
     unit_of_work,
 )
 
 from invenio_requests.customizations import CommentEventType
-from invenio_requests.customizations.event_types import EventType, LogEventType
+from invenio_requests.customizations.event_types import LogEventType
 from invenio_requests.records.api import RequestEventFormat
+from invenio_requests.services.results import EntityResolverExpandableField
 
 
 class RequestEventsService(RecordService):
@@ -33,8 +33,16 @@ class RequestEventsService(RecordService):
         """Wrap schema."""
         return ServiceSchemaWrapper(self, schema)
 
+    @property
+    def expandable_fields(self):
+        """Get expandable fields."""
+        return [
+            EntityResolverExpandableField("created_by")
+        ]
+
     @unit_of_work()
-    def create(self, identity, request_id, data, event_type, uow=None):
+    def create(self, identity, request_id, data, event_type, uow=None,
+               expand=False):
         """Create a request event.
 
         :param request_id: Identifier of the request (data-layer id).
@@ -70,9 +78,11 @@ class RequestEventsService(RecordService):
             event,
             schema=schema,
             links_tpl=self.links_item_tpl,
+            expandable_fields=self.expandable_fields,
+            expand=expand,
         )
 
-    def read(self, identity, id_):
+    def read(self, identity, id_, expand=False):
         """Retrieve a record."""
         event = self._get_event(id_)
         request = self._get_request(event.request_id)
@@ -85,10 +95,13 @@ class RequestEventsService(RecordService):
             event,
             schema=self._wrap_schema(event.type.marshmallow_schema()),
             links_tpl=self.links_item_tpl,
+            expandable_fields=self.expandable_fields,
+            expand=expand,
         )
 
     @unit_of_work()
-    def update(self, identity, id_, data, revision_id=None, uow=None):
+    def update(self, identity, id_, data, revision_id=None, uow=None,
+               expand=False):
         """Update a comment (only comments can be updated)."""
         event = self._get_event(id_)
         request = self._get_request(event.request.id)
@@ -118,6 +131,8 @@ class RequestEventsService(RecordService):
             event,
             schema=schema,
             links_tpl=self.links_item_tpl,
+            expandable_fields=self.expandable_fields,
+            expand=expand,
         )
 
     @unit_of_work()
@@ -148,8 +163,6 @@ class RequestEventsService(RecordService):
         )
 
         self.create(identity, request_id, data, LogEventType, uow=uow)
-
-        uow.register(IndexRefreshOp(index=self.record_cls.index))
         return True
 
     def search(self, identity, request_id, params=None, es_preference=None,
@@ -158,6 +171,8 @@ class RequestEventsService(RecordService):
         params = params or {}
         params.setdefault("sort", "oldest")
 
+        expand = kwargs.pop("expand", False)
+
         # Permissions - guarded by the request's can_read.
         request = self._get_request(request_id)
         self.require_permission(identity, "read", request=request)
@@ -183,7 +198,9 @@ class RequestEventsService(RecordService):
                 self.config.links_search,
                 context={"request_id": request_id, "args": params},
             ),
-            links_item_tpl=self.links_item_tpl
+            links_item_tpl=self.links_item_tpl,
+            expandable_fields=self.expandable_fields,
+            expand=expand,
         )
 
     # Utilities
